<?php
/* $Id: turkish-iso-8859-9.inc.php,v 2.78 2005/06/12 10:10:11 swix Exp $ */

//son gncelleme:12.12.04(in trapezunta)
// Trke eviri  Bora Aliolu
// mail: boralioglu[at]gmail.{com}
// icq uin: 20940178
// #######################################################
// eviri hakkndaki her trl dzeltme ve nerileriniz
// iin benimle temasa geebilirsiniz...
// #######################################################
// son gncelleme:12.12.04 (in nova roma)
//
//                                       "tempus semper fugit"

$charset = 'iso-8859-9';
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';

$byteUnits = array('Byte', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
$day_of_week = array('Pazar', 'Pazartesi', 'Sal', 'aramba', 'Perembe', 'Cuma', 'Cumartesi');
$month = array('Ocak', 'ubat', 'Mart', 'Nisan', 'Mays', 'Haziran', 'Temmuz', 'Austos', 'Eyll', 'Ekim', 'Kasm', 'Aralk');

// Aadaki deikenin tanmlanmas hakknda daha fazla bilgi iin
// http://www.php.net/manual/en/function.strftime.php sitesine gzatnz

$datefmt = '%B %d, %Y at %I:%M %p';

$timespanfmt = '%s gn, %s saat, %s dakika ve %s saniye';

$strAPrimaryKey = '%s zerinde birincil indeks eklendi';
$strAbortedClients = 'ptal edildi';
$strAbsolutePathToDocSqlDir = 'Ltfen web sunucusu zerinde docSQL dizinine giden tam yolu giriniz  ';
$strAccessDenied = 'Eriim engellendi';
$strAccessDeniedExplanation = 'phpMyAdmin MySQL sunucusuna balanmay denedi  sunucu balanty reddetti. config.inc ierisindeki bilgisayar adresini(host) , kullanc adn ve ifreyi kontrol edin ve MySQL sunucusunun yneticisi tarafndan size verilen bilgiyle uyutuundan emin olun.';
$strAction = 'Eylem';
$strAddAutoIncrement = 'Otomatik artma ekle';
$strAddConstraints = 'Snrlama ekle';
$strAddDeleteColumn = 'Stun alan Ekle/Sil';
$strAddDeleteRow = 'Kriter satr Ekle/Sil';
$strAddDropDatabase = '<b>DROP DATABASE</b> ekle';
$strAddFields = '%s alan(lar) ekle';
$strAddHeaderComment = 'Bala yorum ekle (\\n satr atlar)';
$strAddIfNotExists = 'IF NOT EXISTS ekle';
$strAddIntoComments = 'Yorumlara ekle';
$strAddNewField = 'Yeni alan ekle';
$strAddPrivilegesOnDb = 'Bir sonraki veritaban zerinde yetki ekle';
$strAddPrivilegesOnTbl = 'Bir sonraki tablo zerinde yetki ekle';
$strAddSearchConditions = 'Arama durumu ekle ("where" komutu iin):';
$strAddToIndex = '%s indeks satr ekle';
$strAddUser = 'Yeni kullanc ekle';
$strAddUserMessage = 'Yeni bir kullanc eklediniz.';
$strAddedColumnComment = 'Stun iin eklenmi yorum';
$strAddedColumnRelation = 'Stun iin eklenmi iliki';
$strAdministration = 'Ynetim';
$strAffectedRows = 'Etkilenen satrlar:';
$strAfter = '%s tablosundan sonra';
$strAfterInsertBack = 'nceki sayfaya geri dn';
$strAfterInsertNewInsert = 'Yeni kayt ekle';
$strAfterInsertSame = 'Bu sayfaya geri dn';
$strAll = 'Tm';
$strAllTableSameWidth = 'Btn tablolar ayn genilikte gster';
$strAlterOrderBy = 'Tablo sralamasn una gre deitir';
$strAnIndex = '%s zerinde yeni bir indeks eklendi';
$strAnalyzeTable = 'Tabloyu analiz et';
$strAnd = 'Ve';
$strAny = 'Herhangi';
$strAnyHost = 'Herhangi sunucu';
$strAnyUser = 'Herhangi kullanc';
$strApproximateCount = 'Tahmini olmal. Ayrntl bilgi iin 3.11 FAQ\' sne baknz ';
$strArabic = 'Arapa';
$strArmenian = 'Ermenice';
$strAscending = 'Artan';
$strAtBeginningOfTable = 'Tablo banda';
$strAtEndOfTable = 'Tablo sonunda';
$strAttr = 'zellikler';
$strAutodetect = 'Otomatik';
$strAutomaticLayout = 'Otomatik dzen';

$strBack = 'Geri';
$strBaltic = 'Baltk';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinLogEventType = 'Kayt olay tipi';  
$strBinLogInfo = 'Bilgi';  
$strBinLogName = 'Kayt ismi';
$strBinLogOriginalPosition = 'Orjinal kayt yeri';
$strBinLogPosition = 'Kayt yeri';  
$strBinLogServerId = 'Sunucu ID\`si'; 
$strBinary = 'Binari';
$strBinaryDoNotEdit = 'Binari - dzenlemeyiniz';
$strBinaryLog = 'Binary kayt';  
$strBookmarkAllUsers = 'Btn kullanclarn bu bookmark\'a eriimlerine izin ver';
$strBookmarkDeleted = 'Bookmark silindi.';
$strBookmarkLabel = 'Etiket';
$strBookmarkOptions = 'Yer imi seenekleri';
$strBookmarkQuery = ' SQL sorgusu';
$strBookmarkThis = 'Bu SQL sorgusunu iaretle';
$strBookmarkView = 'Sadece gzat';
$strBrowse = 'Tara';
$strBrowseForeignValues = 'Foreign(yabanc) deerleri tara';
$strBulgarian = 'Bulgarca';
$strBzError = 'phpMyAdmin dump dosyasn  bu php versiyonundaki bozuk bir Bz2 uzants nedeniyle sktrmad. phpMyAdmin dizinindeki configurasyon dosyas iindeki  <code>$cfg[\'BZipDump\']</code>  ynergesini <code>FALSE</code> \'a deitirmeniz gerekmektedir. Bz2 sktrma zelliklerini kullanmak istiyorsanz ,bir sonraki php srmne gncelleme yapmanz gerekmektedir.php hata raporu %s\' e baknz ';
$strBzip = '"bzip"';

$strCSVOptions = 'CSV seenekleri';
$strCalendar = 'Takvim';
$strCannotLogin = 'MySQL seenekleri';
$strCantLoad = '%s uzants yklenemiyor,<br />PHP konfigurasyon dosyasn kontrol ediniz.';
$strCantLoadRecodeIconv = 'Karakter seti dnm iin gerekli olan Iconv veya recode uzantlarn ykleyenemiyor.  Php\'nin bu uzantlara izin vermesini salayn veya phpMyAdmin iinde karakter dnmn devre d braknz...';
$strCantRenameIdxToPrimary = 'Indeks\'i PRIMARY olarak adlandrmazsnz!';
$strCantUseRecodeIconv = 'Uzant raporlar yklenmiken , ne iconv,ne libinconv,ne de recode_string fonksiyonu  kullanlamaz.  Php ayarlarnz kontrol ediniz.';
$strCardinality = 'En nemli';
$strCarriage = 'Enter Karakteri: \\r';
$strCaseInsensitive = 'byk kk harf duyarsz';
$strCaseSensitive = 'byk kk harf duyarl';
$strCentralEuropean = 'Orta Avrupa';
$strChange = 'Deitir';
$strChangeCopyMode = 'Ayn yetkilerle yeni bir kullanc yarat ve :';
$strChangeCopyModeCopy = 'eski kullancy muhafaza et.';
$strChangeCopyModeDeleteAndReload = 'eski kullancy kullanc tablolarndan sil ve sonra yetkileri yeniden ykle.';
$strChangeCopyModeJustDelete = 'eski kullancy kullanc tablolarndan sil.';
$strChangeCopyModeRevoke = 'eskiden kalan btn aktif yetkileri iptal et ve sil.';
$strChangeCopyUser = 'Login bilgisini deitir / Kullanc kopyala';
$strChangeDisplay = 'Grmek istediiniz alan seiniz';
$strChangePassword = 'ifre Deitir';
$strCharset = 'Karakter seti';
$strCharsetOfFile = 'Dosyann karakter seti:';
$strCharsets = 'Karakter setleri';
$strCharsetsAndCollations = 'Karakter setleri ve  karlatrmalar';
$strCheckAll = 'Tmn se';
$strCheckOverhead = 'Batan aaya kontrol et';
$strCheckPrivs = 'mtiyazlar kontrol et';
$strCheckPrivsLong = '&quot;%s&quot; veritaban iin yetkileri kontrol et.';
$strCheckTable = 'Tabloyu kontrol et';
$strChoosePage = 'Ltfen dzenlemek istediiniz sayfay sein';
$strColComFeat = 'Stun yorumlar gsteriliyor';
$strCollation = 'Karlatrma';
$strColumnNames = 'Stun adlar';
$strColumnPrivileges = 'Stuna zg yetkiler';
$strCommand = 'Komut';
$strComments = 'Stun yorum,iliki ve MIME tiplerini ier.';
$strCommentsForTable = 'TABLO YORUMLARI';
$strCompatibleHashing = 'MySQL&nbsp;4.0 uyumlu'; 
$strCompleteInserts = 'Her INSERT komutunda stun adlarn ekle';
$strCompression = 'Sktrma';
$strConfigFileError ='phpMyAdmin konfigurasyon dosyanz okuyamad....<br /> Bu php yorumlama hatas bulduu zaman veya dosyay bulamad zaman meydana gelebilir..<br /> Ltfen aadaki linki kullanarak dosyay direkt olarak arn ve aldnz php hata mesajlarn okuyunuz.ou durumda herhangi bir yerde trnak veya noktal virgl eksiktir<br /> Bo bir sayfayla karlarsanz ,herey yolunda demektir.';
$strConfigureTableCoord = ' Ltfen %s tablosu iin koordinatlar yaplandrnz';
$strConnectionError = 'Balanamyor: geersiz ayarlar.';
$strConnections = 'Balantlar';
$strConstraintsForDumped = 'Dkm yaplm tablolar iin kstlamalar';
$strConstraintsForTable = 'Tablo iin kstlamalar';
$strCookiesRequired = 'Cookieler ak olmaldr.';
$strCopyDatabaseOK = '%s veritaban %s\` e kopyaland.'; 
$strCopyTable = 'Tabloyu (veritaban<b>.</b>tablo) kopyala :';
$strCopyTableOK = '%s tablosu %s zerine kopyaland.';
$strCopyTableSameNames = 'Tabloyu aynsna kopyalayamyor!';
$strCouldNotKill = 'phpMyAdmin  %s ilemini kapatamad. Byk ihtimalle daha nceden kapatlm.';
$strCreate = 'Git';
$strCreateIndex = '%s. stunda yeni bir indeks olutur.';
$strCreateIndexTopic = 'Yeni bir indeks olutur';
$strCreateNewDatabase = 'Yeni veritaban olutur';
$strCreateNewTable = '<b>%s</b> veritaban zerinde yeni bir tablo olutur';
$strCreatePage = 'Yeni sayfa olutur';
$strCreatePdfFeat = 'PDF\'lerin oluturulmas';
$strCreationDates = 'Oluturulma/Gncelleme/Kontrol tarihleri';
$strCriteria = 'Kriter';
$strCroatian = 'Hrvata';
$strCyrillic = 'Kiril';
$strCzech = 'eke';
$strCzechSlovak = 'eke-Slovaka';

$strDBComment = 'Veritaban yorumu:';
$strDBCopy = 'Veritabann uraya kopyala:';  
$strDBGContext = 'erik';
$strDBGContextID = 'erik ID';
$strDBGHits = 'Giriler(hit)';
$strDBGLine = 'Satr';
$strDBGMaxTimeMs = 'Max zaman, ms';
$strDBGMinTimeMs = 'Min zaman, ms';
$strDBGModule = 'Modl';
$strDBGTimePerHitMs = 'Zaman/Giri, ms';
$strDBGTotalTimeMs = 'Toplam zaman, ms';
$strDBRename = 'Veritabann yeniden adlandr';
$strDanish = 'Danimarkaca';
$strData = 'Veri';
$strDataDict = 'Veri szl';
$strDataOnly = 'Sadece veri';
$strDatabase = 'Veritaban';
$strDatabaseEmpty = 'Veritaban ad bo!';
$strDatabaseExportOptions = 'Veritaban dnm ayarlar';
$strDatabaseHasBeenDropped = '%s veritaban kaldrld.';
$strDatabaseNoTable = 'Bu veritaban tablo iermiyor!';
$strDatabases = 'Veritabanlar';
$strDatabasesDropped = '%s veritabanlar baaryla kaldrld.';
$strDatabasesStats = 'Veritaban istatistikleri';
$strDatabasesStatsDisable = 'statistikleri kapat';
$strDatabasesStatsEnable = 'statistikleri a';
$strDatabasesStatsHeavyTraffic = 'Not: Burada veritaban istatistiklerini  amak Web Sunucusu ile MySQL arasnda yksek trafie yol aabilir.';
$strDbPrivileges = 'Veritabanna zg yetkiler';
$strDbSpecific = 'Veritabanna zg';
$strDefault = 'Varsaylan';
$strDefaultValueHelp = 'Varsaylan deerler iin trnak iareti veya slash koymak yerine tek deer giriniz.Mesela : a';
$strDefragment = 'Tabloyu birletir';
$strDelOld = 'Sayfada kullanlmayan tablolara verilmi referanslar bulunuyor. Bu referanslar silmek ister misiniz?';
$strDelayedInserts = 'Gecikmi kayt eklemeleri kullan';
$strDelete = 'Sil';
$strDeleteAndFlush = 'Kullanclar sonra da yetkileri sil.';
$strDeleteAndFlushDescr = 'Bu en ksa yoldur fakat yetkileri yeniden yklemek zaman alabilir.';
$strDeleted = 'Satr silindi.';
$strDeletedRows = 'Silinen satrlar:';
$strDeleting = '%s siliniyor';
$strDescending = 'Azalan';
$strDescription = 'Tanmlama';
$strDictionary = 'szlk';
$strDisableForeignChecks = 'Yabanc anahtar iaretlerini seilemez kl';
$strDisabled = 'Etkin deil';
$strDisplayFeat = 'zellikleri Gster';
$strDisplayOrder = 'Grnm dzeni:';
$strDisplayPDF = 'PDF emasn gster';
$strDoAQuery = '<br /><br />"rnekle sorgu" yap. (joker:%) <br />';
$strDoYouReally = 'Aadaki komutu uygulamak istediinizden emin misiniz? ';
$strDocu = 'Yardm';
$strDrop = 'Kaldr';
$strDropDatabaseStrongWarning = 'Btn bir veritabann YOK ETMEK zeresiniz!';
$strDropSelectedDatabases = 'Seili veritabanlarn kaldr';
$strDropUsersDb = 'Kullanclarla ayn isimlerde olan veritabanlarn kaldr.';
$strDumpSaved = 'Dkm dosyas %s dosyasna kaydedildi';
$strDumpXRows = 'Satr says : %s    %s .satrdan balayarak.';
$strDumpingData = 'Tablo dkm verisi';
$strDynamic = 'deiken';

$strEdit = 'Dzenle';
$strEditPDFPages = ' PDF Sayfalarn dzenle';
$strEditPrivileges = 'ncelikleri Dzenle';
$strEffective = 'Efektif';
$strEmpty = 'Boalt';
$strEmptyResultSet = 'MySQL bo bir sonu kmesi dndrd ( sfr satr).';
$strEnabled = 'Etkin';
$strEncloseInTransaction = 'lemlerde dntr ekle';
$strEnd = 'Son';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEnglish = 'ngilizce';
$strEnglishPrivileges = ' Not: MySQL  yetki adlar ngilizce olarak belirtilmitir ';
$strError = 'Hata';
$strEscapeWildcards = '_ ve % jokerleri harfi harfine kullanlmak isteniyorsa \ ile beraber kullanlmaldr.';
$strEstonian = 'Estonyaca';
$strExcelEdition = 'Excel tipi';
$strExcelOptions = 'Excel ayarlar';
$strExecuteBookmarked = 'aretlenmi sorguyu altr';
$strExplain = 'SQL\'i akla';
$strExport = 'Dntr';
$strExtendedInserts = 'Tablo ismini ve INSERT deyimini sadece bir kez kullan';
$strExtra = 'Ekstra';

$strFailedAttempts = 'Baarsz denemeler';
$strField = 'Alan';
$strFieldHasBeenDropped = '%s alan kaldrlmtr';
$strFields = 'Alanlar';
$strFieldsEmpty = ' Alan says bo! ';
$strFieldsEnclosedBy = 'Kapatma karakteri';
$strFieldsEscapedBy = 'Ka karakteri';
$strFieldsTerminatedBy = 'Alan sonu karakteri';
$strFileAlreadyExists = '%s dosyas zaten serverda mevcut, dosya adn deitirin veya zerine yaz seeneini sein! ';
$strFileCouldNotBeRead = 'Dosya okunamad';
$strFileNameTemplate = 'Dosya ismi ablonu';
$strFileNameTemplateHelp = 'Veritaban ismi iin __DB__ , tablo ismi iin __TABLE__ ve  zaman bildirimi iin %sherhangi bir strftime%s deeri kullann,uzant otomatik olarak eklenecek,herhangi dier bir metin korunacaktr.';
$strFileNameTemplateRemember = 'ablonu hatrla';
$strFixed = 'Sabit';
$strFlushPrivilegesNote = 'Not: phpMyAdmin kullanclarn yetkilerini direkt olarak MySQL\'n yetki tablolarndan alr.Bu tablolarn ierikleri eer elle  deiiklik yaplmsa sunucunun kulland yetkilerden farkl olabilir.Bu durumda devam etmeden nce %syetkileri yeniden yklemeniz gerekir%s .';
$strFlushTable = 'Tabloyu yeniden ykle("FLUSH")';
$strFormEmpty = 'Form\'da eksik deer !';
$strFormat = 'Biim';
$strFullText = 'Tm metinler';
$strFunction = 'Fonksiyon';

$strGenBy = 'retildi:';
$strGenTime = 'kt Tarihi';
$strGeneralRelationFeat = 'Genel iliki zellikleri';
$strGeorgian = 'Grcce';
$strGerman = 'Almanca';
$strGlobal = 'genel';
$strGlobalPrivileges = 'Global yetkiler';
$strGlobalValue = 'Global deer';
$strGo = 'Git';
$strGrantOption = 'Hak';
$strGreek = 'Yunanca';
$strGzip = '"gzip"';

$strHasBeenAltered = 'dzenlendi.';
$strHasBeenCreated = 'yaratld.';
$strHaveToShow = 'Grntlemek iin en az bir stun semelisiniz';
$strHebrew = 'branice';
$strHexForBinary = 'Binari alanlar iin onaltlk say sistemini kullan.';
$strHome = 'Ana Sayfa';
$strHomepageOfficial = 'phpMyAdmin Web Sayfas';
$strHost = 'Sunucu';
$strHostEmpty = 'Sunucu ismi alan bo!';
$strHungarian = 'Macarca';

$strIcelandic = 'zlandaca';
$strId = 'ID';
$strIdxFulltext = 'Tm metinler';
$strIfYouWish = 'Eer bir tablo\'nun sadece baz stunlarn yklemek istiyorsanz,virgllerle ayrlm bir alan listesi belirtiniz.';
$strIgnore = 'Yoksay';
$strIgnoreInserts = 'Kayt eklemeleri yoksay kullan';
$strIgnoringFile = '%s dosyasn yoksayyor';
$strImportDocSQL = 'docSQL dosyalarn dntr ';
$strImportFiles = 'Dosyalar dntr';
$strImportFinished = 'Dntrme bitti';
$strInUse = 'kullanmda';
$strIndex = 'ndeks';
$strIndexHasBeenDropped = '%s indeks\'i silindi.';
$strIndexName = 'ndeks ismi :';
$strIndexType = 'ndeks tipi :';
$strIndexWarningMultiple = '`%s` stunu iin birden fazla %s anahtar yaratld. ';
$strIndexWarningPrimary = 'PRIMARY ve INDEX anahtarlarnn ikisine birden `%s` stunu iin deer verilemez.';
$strIndexWarningTable = '`%s` tablosunun indexleri ile ilgili sorunlar';
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';
$strIndexes = 'ndeksler';
$strInnodbStat = 'InnoDB durumu';
$strInsecureMySQL = 'Konfigurasyon dosyanz (ifresiz root) varsaylan MySQL yetki dosyasyla aynen uyuan ayarlar ieriyor.MySQL sunucunuz bu varsaylan ayarlarla alyor,dardan girie ak,ve bu gvenlik an hemen dzeltmeniz gerekmektedir.';
$strInsert = 'Ekle';
$strInsertAsNewRow = 'Yeni satr olarak ekle';
$strInsertBookmarkTitle = 'Ltfen bookmark baln ekleyin'; 
$strInsertNewRow = 'Yeni satr ekle';
$strInsertTextfiles = 'Tablo iine metin dosyas ekle';
$strInsertedRowId = 'Satr id\'si eklendi:';
$strInsertedRows = 'Eklenen satrlar:';
$strInstructions = 'Talimatlar';
$strInternalNotNecessary = '* InnoDb\'nin iinde zaten bir i iliki  var ise gerekli deildir.';
$strInternalRelations = ' ilikiler';

$strJapanese = 'Japonca';
$strJumpToDB = '&quot;%s&quot; veritabanna git.';
$strJustDelete = 'Kullanclar yetki tablolarndan sil .';
$strJustDeleteDescr = '&quot;silinmi&quot; kullanclar, yetkiler yeniden yklenmedike ,hala sunucuya normaldeki gibi eriilebilecek ';

$strKeepPass = 'ifreyi deitirme';
$strKeyname = 'Anahtar ismi';
$strKill = 'Kapat';
$strKorean = 'Korece';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX seenekleri';
$strLandscape = 'Peyzaj';
$strLatexCaption = 'Tablo bal';
$strLatexContent = '__TABLE__ tablosunun ierii';
$strLatexContinued = '(devam eden)';
$strLatexContinuedCaption = 'devam eden tablo bal';
$strLatexIncludeCaption = 'Tablo baln ier';
$strLatexLabel = 'Etiket anahtar';
$strLatexStructure = '__TABLE__ tablosunun yaps';
$strLatvian = 'Litvanyaca';
$strLengthSet = 'Boyut/Deerler*';
$strLimitNumRows = 'Sayfa bana kayt says :';
$strLineFeed = 'Satr: \\n';
$strLinesTerminatedBy = 'Satr sonu';
$strLinkNotFound = 'Link bulunamad';
$strLinksTo = 'Linkler->';
$strLithuanian = 'Litvanyaca';
$strLoadExplanation = 'En iyi yntem varsaylan olarak iaratlenmi,fakat hata olursa deitirebilirsiniz.';
$strLoadMethod = 'YKLEME yntemi';
$strLocalhost = 'Lokal';
$strLocationTextfile = 'Dosyadan ykle';
$strLogPassword = 'ifre:';
$strLogServer = 'Sunucu';
$strLogUsername = 'Kullanc Ad:';
$strLogin = 'Login';
$strLoginInformation = 'Login bilgisi';
$strLogout = 'k';

$strMIMETypesForTable = 'TABLO MIME TPLER';
$strMIME_MIMEtype = 'MIME-tip';
$strMIME_available_mime = 'Uygun MIME-tipleri';
$strMIME_available_transform = 'Uygun dnmler';
$strMIME_description = 'Tanmlama';
$strMIME_nodescription = 'Bu dnm iin uygun bilgi bulunmamaktadr.<br />Ltfen yazara %s ne yapar diye sorun';
$strMIME_transformation = 'Tarayc dnm';
$strMIME_transformation_note = 'Uygun dnm seeneklerinin listesi ve onlarn  MIME-tip dnmleri iin,  %sdnm tanmlamar%s\'na tklayn';
$strMIME_transformation_options = 'Dnm seenekleri';
$strMIME_transformation_options_note = 'Ltfen dnm seenekleri iin deerleri bu ekili kullanarak giriniz: \'a\',\'b\',\'c\'...<br />Backslash ("\") veya tek trnak ("\'") kullamanz gerekiyorsa, u ekilde kullann : \'\\\\xyz\' veya \'a\\\'b\').';
$strMIME_without = 'talik olarak yazlm MIME-tipleri ayr bir dnm fonksiyonuna sahip deildir.';
$strMaximumSize = 'En byk boyut: %s%s';
$strModifications = 'Deiiklikler kaydedildi';
$strModify = 'Deitir';
$strModifyIndexTopic = 'Indeks dzenle';
$strMoreStatusVars = 'Dier durum deikenleri:';
$strMoveTable = 'Tabloyu (veritaban<b>.</b>tablo) ta :';
$strMoveTableOK = '%s tablosu %s zerine tand.';
$strMoveTableSameNames = 'Tabloyu aynsna tayamyor!';
$strMultilingual = 'oklu dil';
$strMustSelectFile = 'Eklemek istediiniz dosyay semeniz gerekir.';
$strMySQLCharset = 'MySQL karakter seti';
$strMySQLConnectionCollation = 'MySQL balant karlatrmas';
$strMySQLReloaded = 'MySQL yeniden yklendi.';
$strMySQLSaid = 'MySQL kts: ';
$strMySQLServerProcess = ' MySQL %pma_s1%   %pma_s2%  zerinde  %pma_s3% olarak alyor';
$strMySQLShowProcess = 'lemleri gster';
$strMySQLShowStatus = 'MySQL alma zaman bilgisini gster';
$strMySQLShowVars = 'MySQL sistem deikenlerini gster';

$strName = 'sim';
$strNeedPrimaryKey = 'Bu tablo iin birincil anahtar tanmlamanz gerekir.';
$strNext = 'Sonraki';
$strNo = 'Hayr';
$strNoActivity = '%s veya daha fazla saniye boyunca hibir ilem yaplmad, ltfen yeniden giri yapnz';
$strNoDatabases = 'Veritaban yok';
$strNoDatabasesSelected = 'Veritaban seilmedi.';
$strNoDescription = 'Tanmlama yok';
$strNoDropDatabases = '"DROP DATABASE" cmlesi burada kullanlamaz.';
$strNoExplain = 'SQL aklamasn yapma';
$strNoFrames = 'phpMyAdmin frame destekli bir tarayc ile daha iyi almaktadr...';
$strNoIndex = 'Indeks tanmlanmad!';
$strNoIndexPartsDefined = 'Indeks ksm tanmlanmad!';
$strNoModification = 'Deiiklik yok';
$strNoOptions = 'Bu dzenin seei yok';
$strNoPassword = 'ifre yok';
$strNoPermission = 'Web sunucusu  %s dosyasn kaydetmek iin izne sahip deil.';
$strNoPhp = ' PHP kodsuz';
$strNoPrivileges = 'Buna yetkiniz yok';
$strNoQuery = 'SQL sorgusu yok!';
$strNoRights = 'Burada bulunmak iin yeterli haklara sahip deilsiniz!';
$strNoRowsSelected = 'Satr seilmedi';
$strNoSpace = '%s dosyasn kaydetmek iin yeterli alan yok.';
$strNoTablesFound = 'Veritabannda tablo bulunamad.';
$strNoThemeSupport = 'Tema destei bulunmuyor,ltfen ayarlar ve/veya %s dizinindeki temalarnz kontrol ediniz';
$strNoUsersFound = 'Kullanc(lar) bulunamad.';
$strNoValidateSQL = 'SQL dorulamasn yapma';
$strNone = 'Hibiri';
$strNotNumber = 'Ltfen bir say giriniz!';
$strNotOK = 'Tamam deil';
$strNotSet = '<b>%s</b> tablosu bulunamad veya %s iinde tanmlanmad';
$strNotValidNumber = ' geerli bir satr says deil!';
$strNull = 'Bo';
$strNumSearchResultsInTable = '<b><font color=\'blue\'>%s</font></b> ( <b>%s</b> tablosu iinde aramanza uyan kayt says ) ';
$strNumSearchResultsTotal = 'Toplam: %s eleim';
$strNumTables = 'Tablolar';

$strOK = 'Tamam';
$strOftenQuotation = 'Sk kullanlan aktarma iaretleri.SEME BALI,sadece <b>char</b> ve <b>varchar</b> alanlarnn kapatma karakteri ile evrelenecei anlamna gelir..';
$strOperations = 'lemler';
$strOperator = 'lemci';
$strOptimizeTable = 'Tabloyu optimize et';
$strOptionalControls = 'zel karakterleri yazmak ve okumak iin kontroller.Opsiyonel';
$strOptionally = 'Seime Bal';
$strOr = 'veya';
$strOverhead = 'Kullanlamayan Veri';
$strOverwriteExisting = 'Mevcut dosyalarn zerine yaz!';

$strPHP40203 = ' Ciddi bir multi-byte strings (mbstring) hatasna sahip olan PHP 4.2.3 kullanyorsunuz,. PHP hata raporu 19404\' e baknz. Bu srmn phpMyAdmin\'le kullanlmas nerilmez.';
$strPHPVersion = 'PHP Srm';
$strPageNumber = 'Sayfa numaras:';
$strPaperSize = 'Kat boyu';
$strPartialText = 'Ksmi Metinler';
$strPassword = 'ifre';
$strPasswordChanged = '%s iin ifre baaryla deitirildi.';
$strPasswordEmpty = 'ifre alan doldurulmad!';
$strPasswordHashing = 'ifre Hash yntemi';  
$strPasswordNotSame = 'Girilen ifreler ayn deil!';
$strPdfDbSchema = ' "%s" veritabannn emas - Sayfa %s';
$strPdfInvalidTblName = ' "%s" tablosu bulunamyor !';
$strPdfNoTables = 'Tablo yok';
$strPerHour = 'saat bana';
$strPerMinute = 'dakika bana';
$strPerSecond = 'saniye bana';
$strPersian = 'Farsa';
$strPhoneBook = 'telefon defteri';
$strPhp = 'PHP kodu olutur';
$strPmaDocumentation = 'phpMyAdmin yardm';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt>\' nin deeri  konfigurasyon dosyasnn iinde verilmelidir!';
$strPolish = 'Lehce';
$strPortrait = 'Portre';
$strPos1 = 'Balang';
$strPrevious = 'nceki';
$strPrimary = 'Birincil';
$strPrimaryKeyHasBeenDropped = 'Birincil anahtar silindi';
$strPrimaryKeyName = 'PRIMARY KEY TEK olmaldr!';
$strPrimaryKeyWarning = '# PRIMARY <b>sadece</b> birincil bir anahtarn ismi <b>olmaldr!</b>';
$strPrint = 'Yazdr';
$strPrintView = 'Yazc grnts';
$strPrintViewFull = 'Yazc grnts (tm metin)';
$strPrivDescAllPrivileges = 'GRANT hari tm yetkileri ierir.';
$strPrivDescAlter = 'Varolan tablonun yapsnn deitirilmesine izin verir.';
$strPrivDescCreateDb = 'Yeni veritabanlar ve tablolarn oluturulmasna izin verir.';
$strPrivDescCreateTbl = 'Yeni tablolarn oluturulmasna izin verir.';
$strPrivDescCreateTmpTable = 'Geici tablolara oluturulmasna izin verir.';
$strPrivDescDelete = 'Veri silinmesine izin verir.';
$strPrivDescDropDb = 'Veritabanlar ve tablolarn kaldrlmasna izin verir.';
$strPrivDescDropTbl = 'Tablolarn kaldrlmasna izin verir.';
$strPrivDescExecute = 'Kaydedilmi yordamlarn altrlmasna izin verir.; Bu MySQL srmnde etkisi yoktur.';
$strPrivDescFile = 'Data import ve export\'una izin verir.';
$strPrivDescGrant = 'mtiyaz tablolarn yeniden yklemeden yeni kullanc ve yetki eklenmesine izin verir.';
$strPrivDescIndex = 'ndekslerin yaratlmasna ve kaldrlmasna izin verir.';
$strPrivDescInsert = 'Verinin eklenmesine ve yer deitirilmesine izin verir.';
$strPrivDescLockTables = 'Geerli ilem  iin tablolarn kilitlenmesine izin verir.';
$strPrivDescMaxConnections = 'Kullancnn saat bana aabilecei balanty snrlar.';
$strPrivDescMaxQuestions = 'Kullancnn saat bana sunucuya gnderebilecei sorgu saysn snrlar.';
$strPrivDescMaxUpdates = 'Kullancnn,saat bana altrabilecei,herhangi bir tablo veya veritaban deitiren  komut saysn snrlar.';
$strPrivDescProcess3 = 'Dier kullanclarn ilemlerinin kapatlmasna izin verir.';
$strPrivDescProcess4 = 'lem listesindeki btn sorgularn grntlenmesine izin verir.';
$strPrivDescReferences = 'Bu MySQL srmnde etkisi yoktur.';
$strPrivDescReload = 'Sunucu ayarlarnn yeniden yklenmesine ve nbellein silinmesine izin verir';
$strPrivDescReplClient = 'Kullanclara Slave ve Master\'larn nerede olduunu sorma  hakkn verir.';
$strPrivDescReplSlave = 'Kopya slave\'ler iin gerekli.';
$strPrivDescSelect = 'Veri okunmasna izin ver.';
$strPrivDescShowDb = 'Btn veritabanlar listesine eriim verir.';
$strPrivDescShutdown = 'Sunucunun kapatlmasna izin ver.';
$strPrivDescSuper = 'Maksimum balant says alsa bile balanmasna izin ver;Global deikenleri saptamak veya dier kullanclarn ilemlerini sonlandrmak  gibi  bir ok ynetim ilemi iin gereklidir.';
$strPrivDescUpdate = 'Veri deitirilmesine izin ver.';
$strPrivDescUsage = 'mtiyaz yok.';
$strPrivileges = 'mtiyazlar';
$strPrivilegesReloaded = 'Ayrcalklar baaryla yklendi.';
$strProcesslist = 'lem listesi';
$strPutColNames = 'lk satrda alan isimlerini koy';

$strQBE = ' Sorgula';
$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQueryFrame = 'Sorgu penceresi';
$strQueryOnDb = '<b>%s</b> veritabannda SQL sorgusu&nbsp;:';
$strQuerySQLHistory = 'SQL gemii';
$strQueryStatistics = '<b>Sorgu istatistikleri</b>: Balangtan bu yana sunucuya <b>%s</b> sorgu gnderildi.';
$strQueryTime = 'Sorgu  %01.4f san srd';
$strQueryType = 'Sorgu ekli';
$strQueryWindowLock = 'Pencere dndan bu sorgunun zerine yazma';

$strReType = 'Yeniden gir';
$strReceived = 'Alnd';
$strRecords = 'Kaytlar';
$strReferentialIntegrity = 'Referans btnln kontrol et.';
$strRefresh = 'Yenile';
$strRelationNotWorking = 'likili tablolarla almada kullanlan ekstra zellikler kapatld.Nedenini renmek iin %sburaya%s tklaynz...';
$strRelationView = 'liki grnm';
$strRelationalSchema = 'liki emas';
$strRelations = 'likiler';
$strRelationsForTable = 'TABLO LKLER';
$strReloadFailed = 'MySQL yeniden yklenmesi gerekletirilemedi.';
$strReloadMySQL = 'MySQL\' i yeniden ykle';
$strReloadingThePrivileges = 'mtiyazlar yeniden yklyor';
$strRemoveSelectedUsers = 'Seili kullanclar kaldr';
$strRenameDatabaseOK = '%s veritaban %s olarak yeniden adlandrld';
$strRenameTable = 'Tabloyu yeniden adlandr';
$strRenameTableOK = '%s tablosu %s olarak yeniden adlandrld';
$strRepairTable = 'Tablo\'yu onar';
$strReplace = 'Yerdeitir';
$strReplaceNULLBy = 'NULL \' u bununla yerdeitir';
$strReplaceTable = 'Tablo verisini bir dosyadaki ile deitir';
$strReset = 'Sfrla';
$strResourceLimits = 'Kaynak snrlar';
$strRevoke = 'Geersiz kl';
$strRevokeAndDelete = 'Kullanclardaki tm etkin yetkileri geersiz kl  ve sonra sil..';
$strRevokeAndDeleteDescr = 'Kullanclar yeniden yklenene kadar  hala KULLANIM ayrcalna  sahip olacaklar.';
$strRevokeMessage = '%s\'in nceliklerini kaldrdnz';
$strRomanian = 'Romence';
$strRowLength = 'Satr boyu';
$strRowSize = ' Satr boyutu ';
$strRows = 'Satr';
$strRowsFrom = 'kayt : Balayaca kayt :';
$strRowsModeFlippedHorizontal = 'yatay (dndrlm balklar)';
$strRowsModeHorizontal = 'yatay';
$strRowsModeOptions = '%s olarak gster ve %s hcre sonra bal tekrarla.';
$strRowsModeVertical = 'dikey';
$strRowsStatistic = 'Satr istatistii';
$strRunQuery = 'Sorguyu altr';
$strRunSQLQuery = '<b>%s</b> veritaban zerinde sorgu altr';
$strRunning = '# %s zerinde alyor...';
$strRussian = 'Rusa';

$strSQL = 'SQL sorgusu';
$strSQLExportType = 'Export tipi';
$strSQLOptions = 'SQL seenekleri';
$strSQLParserBugMessage = 'SQL yorumlaycsnda bir hata bulma ihtimaliniz var.Ltfen sorgunuzu dikkatli bir ekilde gzden geiriniz,ve trnaklar doru ve yanl yazlmam kontrol ediniz.Dier olas hata nedenleri metin alanna alabilecei boyuttan daha byk bir dosya yklyor olma ihtimalinizdir.Sorgunuzu MySQL komut satr arayznde de deneyebilirsiniz..MySQL sunucu hata kts,var ise,hatay manzda size yardmc olabilir.Hala sorunlarnz varsa veya  komut satr arayz alrken,yorumlayc hata veriyorsa,ltfen SQL sorgu giriinizi hata yaratan tek bir sorguya indirgeyin,ve aadaki CUT blm veri yn ile birlikte hata raporunu bildiriniz:';
$strSQLParserUserError = 'SQL sorgunuzda bir hata varm gibi gzkyor.MySQL sunucu hata kts,var ise,hatay bulmanzda size yardmc olabilir.';
$strSQLQuery = 'SQL sorgusu';
$strSQLResult = 'SQL sonucu';
$strSQPBugInvalidIdentifer = 'Geersiz tanmlayc';
$strSQPBugUnclosedQuote = 'Kapatlmam trnak';
$strSQPBugUnknownPunctuation = 'Bilinmeyen noktalama iareti';
$strSave = 'Kaydet';
$strSaveOnServer = 'Sunucuda %s dizininin iinde kaydet';
$strScaleFactorSmall = 'arpan faktr sayfadaki ema iin ok kk';
$strSearch = 'Ara';
$strSearchFormTitle = 'Veritabannda ara';
$strSearchInTables = 'Tablo iinde ara :';
$strSearchNeedle = 'Aranacak kelime veya deerler ( joker: "%" ):';
$strSearchOption1 = 'kelimelerin en azndan biri';
$strSearchOption2 = 'btn kelimeler';
$strSearchOption3 = 'tam eleim';
$strSearchOption4 = 'normal deyim gibi';
$strSearchResultsFor = ' "%s" %s iin arama sonular:';
$strSearchType = '<b>BUL </b> :';
$strSecretRequired = 'Ayar dosyas iin gizli bir ifre gerekiyor (blowfish_secret).';
$strSelectADb = ' Ltfen bir veritaban seiniz';
$strSelectAll = 'Tmn se';
$strSelectBinaryLog = 'Grntlemek istediiniz binari kaydn seiniz';  
$strSelectFields = 'Alan se (en az bir)';
$strSelectNumRows = 'sorgu ierisinde';
$strSelectTables = 'Tablolar se';
$strSend = 'Dosya olarak kaydet';
$strSent = 'Gnderildi';
$strServer = 'Sunucusu';
$strServerChoice = 'Server seimi';
$strServerNotResponding = 'Sunucu yant vermiyor';
$strServerStatus = 'alma bilgisi';
$strServerStatusUptime = 'Bu MySQL sunucusunun alma sresi : %s <br /> Balama Zaman: %s ';
$strServerTabProcesslist = 'lemler';
$strServerTabVariables = 'Deikenler';
$strServerTrafficNotes = '<b>Sunucu Younluu</b>: Bu tablolar balama zamanndan bu yana  MySQL sunucusunun network younluunu gsterir.';
$strServerVars = 'Sunucu deikenleri ve ayarlar';
$strServerVersion = 'Server srm';
$strSessionValue = 'Oturum deeri';
$strSetEnumVal = 'Eer alan tipi "enum" veya "set" ise verileri u formata gre giriniz: \'a\',\'b\',\'c\'...<br />Eer bu deerler arasna backslash ("\") veya tek trnak koymanz gerekirse (\'),bunun iin backslash kullann.Mesela: \'\\\\xyz\' veya \'a\\\'b\') gibi.';
$strShow = 'Gster';
$strShowAll = 'Tmn gster';
$strShowColor = 'Rengi gster';
$strShowDatadictAs = 'Veri szl format';
$strShowFullQueries = 'Sorgularn tmn gster';
$strShowGrid = 'Izgaray gster';
$strShowPHPInfo = 'PHP bilgisini gster';
$strShowTableDimension = 'Tablolarn';
$strShowTables = 'Tablolar gster';
$strShowThisQuery = 'Sorguyu burada yine gster.';
$strShowingRecords = 'Kaytlar gsteriyor...';
$strSimplifiedChinese = 'Basitletirilmi ince';
$strSingly = '( birer birer )';
$strSize = 'Boyut';
$strSlovak = 'Slovaka';
$strSlovenian = 'Slovence';
$strSort = 'Srala';
$strSortByKey = 'Anahtara gre srala';
$strSpaceUsage = 'Kullanlan alan';
$strSpanish = 'spanyolca';
$strSplitWordsWithSpace = 'Kelimelerin arasnda boluk olmaldr (" ").';
$strStatCheckTime = 'Son kontrol';
$strStatCreateTime = 'Oluturulma';
$strStatUpdateTime = 'Son gncellenme';
$strStatement = 'Durum';
$strStatus = 'Durum';
$strStrucCSV = 'CSV verisi';
$strStrucData = 'Yap ve Veri';
$strStrucDrop = 'DROP TABLE ekle';
$strStrucExcelCSV = 'MS Excel verisi iin CSV';
$strStrucNativeExcel = 'MS Excel verisi';
$strStrucOnly = 'Sadece yap';
$strStructPropose = 'Tablo yapsn analiz et.';
$strStructure = 'Yap';
$strSubmit = 'Onayla';
$strSuccess = 'SQL sorgunuz baaryla altrlmtr';
$strSum = 'toplam';
$strSwedish = 'svece';
$strSwitchToDatabase = 'Kopyalanm veritabann kullan.';  
$strSwitchToTable = 'Kopyalanm tabloya ge';

$strTable = 'Tablo:';
$strTableComments = 'Tablo yorumlar';
$strTableEmpty = 'Tablo ismi bo!';
$strTableHasBeenDropped = '%s tablosu kaldrlmtr';
$strTableHasBeenEmptied = '%s tablosu boaltlmtr';
$strTableHasBeenFlushed = '%s tablosu baaryla kapatlmtr.';
$strTableMaintenance = 'Tablo bakm';
$strTableOfContents = 'erik tablosu';
$strTableOptions = 'Tablo ayarlar';
$strTableStructure = 'Tablo yaps :';
$strTableType = 'Tablo tipi';
$strTables = '%s tablo';
$strTakeIt = 'Se';
$strTblPrivileges = 'Tabloya zg yetkiler';
$strTextAreaLength = 'Boyutu nedeniyle,<br /> bu alan dzenlenmeyebilir ';
$strThai = 'Thai';
$strTheContent = 'Dosyanzn ierii eklendi.';
$strTheContents = 'Dosyann ierii tablonun ieriini ayn birincil veya unique anahtar deerli stunlar iin yer deitirir..';
$strTheTerminator = 'Alan bitimini belirten iaret.';
$strTheme = 'Tema / Sitil';
$strThisHost = 'Bu host ';
$strThisNotDirectory = 'Bu bir dizin deildi';
$strThreadSuccessfullyKilled = '%s ilemi  baaryla sonlandrld.';
$strTime = 'Zaman';
$strToggleScratchboard = 'scratchboard\a ge';
$strTotal = 'toplam';
$strTotalUC = 'Toplam';
$strTraditionalChinese = 'Geleneksel ince';
$strTraditionalSpanish = 'Geleneksel spanyolca';
$strTraffic = 'Younluk';
$strTransformation_application_octetstream__download = 'Bir alandaki binari veriyi yklemek iin link gster.lk seenek binari dosya addr.kinci seenek ise dosya adn ieren tablo satrrn olas alan addr.kinci bir seenek istiyorsanz ilk seenei bo brakmalsnz.';
$strTransformation_image_jpeg__inline = 'Tklanabilir bir thumbnail gsterir; seenekler: pixel olarak genilik,ykseklik (orijinal oran korunur)';
$strTransformation_image_jpeg__link = 'Bu resime direkt bir link gsterir (direct blob yklemesi...).';
$strTransformation_image_png__inline = 'jpeg resmini gr: satrii';
$strTransformation_text_plain__dateformat = 'Bir TIME, TIMESTAMP veya DATETIME alan alr ve varsaylan tarih format bilgilerinizle onu yeniden biimlendirir.lk seenek  zamangsterimi(timestamp)\'ne eklenecek bir offset(saat olarak)\'tir.(Varsaylan: 0).kinci seenek PHP\'nin strftime() fonksiyonu iin uygun olan parametrelere gre farkl bir  zamangsterimi(timestamp)\'dir.';
$strTransformation_text_plain__external = 'D bir uygulama altrr ve alanverisini standart giri yoluyla besler.Uygulamann standart kts dner.Varsaylan ho bir HTML kts veren Tidy(Dzenli)\'dir..Gvenlik nedeniyle libraries/transformations/text_plain__external.inc.php dosyasn elle dzenlemeniz ve almasna izin vereceiniz aralar eklemeniz gerekir.lk seenek;altrmak istediiniz program says,ikinci seenek ise program iin gerekli olan parametrelerdir.nc parametre ,eer 1\'e setlenmise htmlspecialchars() fonksiyonunu kullanarak kty dntrecektir(Varsaylan: 1).Drdnc bir parametre ise ,eer 1\'e setlenmise NOWRAP(kaydrma yok) kodu tm hcreye eklenecek ve btn kt yeniden dzenlenmeden grnecektir.(Varsaylan :1)';
$strTransformation_text_plain__formatted = 'Alann orijinal biimlendirmesini korur.Escaping(ka) yaplmaz..';
$strTransformation_text_plain__imagelink = 'Bir resim ve bir link gsterir,alan dosya ismini ierir;ilk seenek "http://domain.com/" gibi bir yazm,ikinci seenek pixel olarak genilik,ncs ise yksekliktir.';
$strTransformation_text_plain__link = 'Bir link ve dosya ismini ieren alan gsterir;ilk seenek "http://domain.com/" gibi bir gsterim,ikincisi ise link iin bir balktr.';
$strTransformation_text_plain__substr = 'Sadece yaznn bir ksmn gsterir. lk seenek metin ktnzn nerede olduunu tanmlamak iin kullanlacak bir offset\'tir. (varsaylan: 0).kinci seenek ne kadar metinin geri dndrldn belirten bir offset\'tir.. Eer bosa, btn kalan metin geri dndrlr.nc seenek bir substring dndrldnde hangi karakterlerin ktnn sonuna ekleneceini tanmlar(Varsaylan:...) .';
$strTruncateQueries = 'Grlen sorgular ksalt';
$strTurkish = 'Trke';
$strType = 'Tip';

$strUkrainian = 'Ukraynaca';
$strUncheckAll = 'Hibirisini Seme';
$strUnicode = 'Unicode';
$strUnique = 'Unique';
$strUnknown = 'bilinmeyen';
$strUnselectAll = 'Hibirisini seme';
$strUpdComTab = 'Stun_Yorumlar tablosunun nasl gncellendiini renmek istiyorsanz Dkmanlara baknz.';
$strUpdatePrivMessage = '%s iin olan yetkileri gncellediniz.';
$strUpdateProfileMessage = 'Profil gncellendi.';
$strUpdateQuery = 'Sorguyu gncelle';
$strUpgrade = '%s %s veya daha sonraki bir srme ykseltme yapmanz gereklidir.';
$strUsage = 'Kullanm';
$strUseBackquotes = 'Tablo ve alan isimleri iin ters trnak " ` " iaretini kullan';
$strUseHostTable = 'Host tablosunu kullan';
$strUseTabKey = 'Deerden deere gemek iin TAB tuunu istediiniz herhangi bir yere gitmek iin CTRL+OK TULARI\`n kullann.';
$strUseTables = 'Tablolar kullan';
$strUseTextField = 'Metin alann kullan';
$strUseThisValue = 'Bu deeri kullan';
$strUser = 'Kullanc';
$strUserAlreadyExists = '%s kullancs zaten mevcut!';
$strUserEmpty = 'Kullanc ismi alan doldurulmad!';
$strUserName = 'Kullanc ismi';
$strUserNotFound = 'Seili kullanc yetki tablosunda bulunamad.';
$strUserOverview = 'Kullanc gzlem';
$strUsersDeleted = 'Seili kullanclar baaryla silindi.';
$strUsersHavingAccessToDb = '&quot;%s&quot; veritabanna eriimi olan kullanclar';

$strValidateSQL = 'SQL\'i dorula';
$strValidatorError = 'SQL onaylaycs balatlamad.%sdkmanlar%s\'da belirtildii gibi,gerekli php uzantlarnn yklenip yklenilmediini kontrol ediniz.';
$strValue = 'Deer';
$strVar = 'Deiken';
$strViewDump = 'Tablo dkm emas';
$strViewDumpDB = 'Veritaban dkm emas';
$strViewDumpDatabases = 'Veritabanlar dkm emas';

$strWebServerUploadDirectory = 'web sunucu ykleme dizini';
$strWebServerUploadDirectoryError = 'Ykleme  iin belirttiiniz dizine ulalamyor.';
$strWelcome = '%s srmne HOGELDNZ....';
$strWestEuropean = 'Bat Avrupa';
$strWildcard = 'joker';
$strWindowNotFound = 'Hedefteki taray penceresi gncellenemiyor...Balants olan pencereyi kapattnz veya taraycnzn gvenlik ayarlar buna izin vermiyor';
$strWithChecked = 'Seilileri:';
$strWritingCommentNotPossible = 'Yorum yazlmas mmkn deil.';
$strWritingRelationNotPossible = 'liki yazlmas mmkn deil.';
$strWrongUser = 'Hatal kullanc ad/parola. Eriim engellendi.';

$strXML = 'XML';

$strYes = 'Evet';

$strZeroRemovesTheLimit = 'Not: Bu seeneklerin 0\'a ayarlanmas snr kaldrr..';
$strZip = '"ziplenmi"';

$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
?>
